<?php

namespace GivePaytm\Paytm\API\Models;

/**
 * Class Transaction
 *
 * @since 1.1.1
 */
class Transaction {
	/**
	 * @var string $txnId
	 * @since 1.1.1
	 */
	public $txnId;

	/**
	 * @var int $orderId
	 * @since 1.1.1
	 */
	public $orderId;

	/**
	 * @var string $txnAmount
	 * @since 1.1.1
	 */
	public $txnAmount;

	/**
	 * @var string $resultStatus
	 * @since 1.1.1
	 */
	public $resultStatus;

	/**
	 * @var string $resultCode
	 * @since 1.1.1
	 */
	public $resultCode;

	/**
	 * @var string $resultMsg
	 * @since 1.1.1
	 */
	public $resultMsg;

	/**
	 * This function should be used to create transaction model object.
	 *
	 * @since 1.1.1
	 */
	public static function makeObject( object $paytmTransactionData ): self {
		$self = new self();

		$self->txnId        = $paytmTransactionData->body->txnId;
		$self->orderId      = absint( $paytmTransactionData->body->orderId );
		$self->txnAmount    = $paytmTransactionData->body->txnAmount;
		$self->resultStatus = $paytmTransactionData->body->resultInfo->resultStatus;
		$self->resultCode   = $paytmTransactionData->body->resultInfo->resultCode;
		$self->resultMsg    = $paytmTransactionData->body->resultInfo->resultMsg;

		return $self;
	}

	/**
	 * This function should be used to create transaction model object.
	 *
	 * @since 1.1.1
	 */
	public static function makePaytmPostedData( array $paytmTransactionData ): self {
		$self = new self();

		$self->txnId        = $paytmTransactionData['TXNID'];
		$self->orderId      = absint( $paytmTransactionData['ORDERID'] );
		$self->txnAmount    = $paytmTransactionData['TXNAMOUNT'];
		$self->resultStatus = $paytmTransactionData['STATUS'];
		$self->resultCode   = $paytmTransactionData['RESPCODE'];
		$self->resultMsg    = $paytmTransactionData['RESPMSG'];

		return $self;
	}

	/**
	 * @since 1.1.1
	 */
	public function isTransactionSuccessful(): bool {
		return 'TXN_SUCCESS' === $this->resultStatus;
	}

	/**
	 * @since 1.1.1
	 */
	public function isTransactionPending(): bool {
		return 'PENDING' === $this->resultStatus;
	}

	/**
	 * @since 1.1.1
	 */
	public function isTransactionFailed(): bool {
		return in_array( $this->resultStatus, [ 'TXN_FAILURE', 'NO_RECORD_FOUND' ] );
	}
}
