<?php

namespace GivePaytm\Paytm\API;

use GivePaytm\Paytm\Models\Merchant;
use GivePaytm\Vendors\paytm\paytmchecksum\PaytmChecksum;
use RuntimeException;

/**
 * Class Request
 *
 * @since 1.1.1
 */
abstract class Request {
	/**
	 * Paytm merchant.
	 *
	 * @var Merchant $merchant
	 * @since 1.1.1
	 */
	protected $merchant;

	/**
	 * Class constructor.
	 *
	 * @since 1.1.1
	 */
	public function __construct() {
		$this->merchant = Merchant::make();
	}

	/**
	 * Get request url.
	 * @since 1.1.1
	 */
	protected function getRequestUrl( string $requestUrlPrefix ): string {
		return $this->merchant->getRequestEndpoint() . $requestUrlPrefix;
	}

	/**
	 * Execute request.
	 *
	 * @since 1.1.1
	 */
	protected function execute( string $requestUrl, array $requestArgs ): object {
		$requestArgs = [
			'body' => $requestArgs,
			'head' => [
				'signature' => PaytmChecksum::generateSignature(
					wp_json_encode( $requestArgs ),
					$this->merchant->accessKey
				),
				'channelId' => 'WEB'
			]
		];

		$requestArgs = [
			'headers'     => [ 'Content-Type' => 'application/json' ],
			'body'        => wp_json_encode( $requestArgs ),
			'data_format' => 'body'
		];

		$response = wp_remote_post( $this->getRequestUrl( $requestUrl ), $requestArgs );

		if ( is_wp_error( $response ) ) {
			throw new RuntimeException( $response->get_error_message() );
		}

		if( 503 === wp_remote_retrieve_response_code( $response ) ) {
			throw new RuntimeException( 'Paytm Service is unavailable to process request.' );
		}

		return json_decode( wp_remote_retrieve_body( $response ), false );
	}
}
