<?php

namespace GivePaytm\Paytm\API;

/**
 * Class Translations
 *
 * @since 1.1.1
 */
class Translations {
	/**
	 * This function should be used to get translation.
	 *
	 * @since 1.1.1
	 * @return mixed|null
	 */
	public function getTranslation( string $type, string $errorCode ) {
		$errorCodes = $this->getTranslations()[ $type ] ?? [];

		return $errorCodes[ $errorCode ] ?? null;
	}

	/**
	 * This function should be used to get translations.
	 *
	 * @since 1.1.1
	 */
	protected function getTranslations(): array {
		return [
			'initiateTransaction' => [
				'0000'     => esc_html__( 'Success', 'give-paytm' ),
				'0002'     => esc_html__( 'Success Idempotent', 'give-paytm' ),
				'196'      => esc_html__( 'Payment failed as amount entered exceeds the allowed limit. Please enter a lower amount and try again or reach out to the merchant for further assistance.',
					'give-paytm' ),
				'1006'     => esc_html__( 'Your Session has expired', 'give-paytm' ),
				'1007'     => esc_html__( 'Missing mandatory element', 'give-paytm' ),
				'1008'     => esc_html__( 'Pipe character is not allowed', 'give-paytm' ),
				'1011'     => esc_html__( 'Invalid Promo Param', 'give-paytm' ),
				'1012'     => esc_html__( 'Promo amount cannot be more than transaction amount', 'give-paytm' ),
				'2004'     => esc_html__( 'SSO Token is invalid', 'give-paytm' ),
				'2005'     => esc_html__( 'Checksum provided is invalid', 'give-paytm' ),
				'2007'     => esc_html__( 'Txn amount is invalid', 'give-paytm' ),
				'2013'     => esc_html__( 'Mid in the query param doesn’t match with the Mid sent in the request',
					'give-paytm' ),
				'2014'     => esc_html__( 'OrderId in the query param doesn’t match with the OrderId sent in the request',
					'give-paytm' ),
				'2023'     => esc_html__( 'Repeat Request Inconsistent', 'give-paytm' ),
				'00000900' => esc_html__( 'System error', 'give-paytm' )
			],
			'transactionStatus'   => [
				'01'  => esc_html__( 'Txn Success', 'give-paytm' ),
				'227' => esc_html__( 'Your payment has been declined by your bank. Please contact your bank for any queries. If money has been deducted from your account, your bank will inform us within 48 hrs and we will refund the same.',
					'give-paytm' ),
				'235' => esc_html__( 'Wallet balance Insufficient, bankName=WALLET', 'give-paytm' ),
				'295' => esc_html__( 'Your payment failed as the UPI ID entered is incorrect. Please try again by entering a valid VPA or use a different method to complete the payment.',
					'give-paytm' ),
				'331' => esc_html__( 'No Record Found', 'give-paytm' ),
				'334' => esc_html__( 'Invalid Order ID', 'give-paytm' ),
				'335' => esc_html__( 'Mid is invalid', 'give-paytm' ),
				'400' => esc_html__( 'Transaction status not confirmed yet.', 'give-paytm' ),
				'401' => esc_html__( 'Your payment has been declined by your bank. Please contact your bank for any queries. If money has been deducted from your account, your bank will inform us within 48 hrs and we will refund the same.',
					'give-paytm' ),
				'402' => esc_html__( 'Looks like the payment is not complete. Please wait while we confirm the status with your bank.',
					'give-paytm' ),
				'501' => esc_html__( 'Server Down', 'give-paytm' ),
				'810' => esc_html__( 'Txn Failed', 'give-paytm' ),
				'843' => esc_html__( 'Your transaction has been declined by the bank. Remitting account is blocked or frozen.',
					'give-paytm' ),
				'820' => esc_html__( 'Mobile number linked to your bank account has changed. Please contact your bank and use different payment method to complete the payment',
					'give-paytm' ),
				'267' => esc_html__( 'Your payment has been declined by your bank since at least a 24 hours gap is not maintained between successful pre-notify and mandate execution. Please try again later.',
					'give-paytm' )
			]
		];
	}
}
