<?php

namespace GivePaytm\Paytm\Models;

use RuntimeException;

/**
 * Class Merchant
 *
 * @since 1.1.1
 */
class Merchant {
	/**
	 * @var string $environment
	 * @since 1.1.1
	 */
	public $environment;

	/**
	 * @var string $merchantId
	 * @since 1.1.1
	 */
	public $merchantId;

	/**
	 * @var string $accessKey
	 * @since 1.1.1
	 */
	public $accessKey;

	/**
	 * @var string $websiteName
	 * @since 1.1.1
	 */
	public $websiteName;

	/**
	 * This function should be used to create merchant object.
	 *
	 * @param null $mode
	 *
	 * @return Merchant
	 */
	public static function make( $mode = null ): Merchant {
		$self = new self();

		if ( ! $mode ) {
			$self->environment = give_is_test_mode() ? 'staging' : 'live';
		}

		if ( 'live' === $self->environment ) {
			$self->merchantId  = give_get_option( 'paytm_live_merchant_id' );
			$self->accessKey   = give_get_option( 'paytm_live_mer_access_key' );
			$self->websiteName = give_get_option( 'paytm_live_website_name' );

			return $self;
		}

		if ( 'staging' === $self->environment ) {
			$self->merchantId  = give_get_option( 'paytm_sandbox_merchant_id' );
			$self->accessKey   = give_get_option( 'paytm_sandbox_mer_access_key' );
			$self->websiteName = give_get_option( 'paytm_sandbox_website_name' );

			return $self;
		}

		throw new RuntimeException( 'Invalid environment' );
	}

	/**
	 * Get request endpoint.
	 *
	 * @since 1.1.1
	 */
	public function getRequestEndpoint( string $env = null ): string {
		if ( ! $env ) {
			$env = $this->environment;
		}

		if ( 'live' === $env ) {
			return 'https://securegw.paytm.in';
		}

		if ( 'staging' === $env ) {
			return 'https://securegw-stage.paytm.in';
		}

		throw new RuntimeException( 'Invalid environment' );
	}
}
