<?php

namespace GivePaytm\Paytm;

use Give\Framework\PaymentGateways\PaymentGatewayRegister;
use GivePaytm\Paytm\API\Translations;
use GivePaytm\Paytm\Controllers\HandleProcessPaymentRedirect;
use GivePaytm\Paytm\Models\Merchant;
use GivePaytm\Paytm\Repositories\Settings;

/**
 * Class ServiceProvider
 *
 * This class is used to register service provider.
 *
 * @since 1.1.1
 */
class ServiceProvider implements \Give\ServiceProviders\ServiceProvider {

	/**
	 * @since 1.1.1
	 */
	public function register(): void {
		give()->singleton( Settings::class );
		give()->singleton( Translations::class );
		give()->singleton( Merchant::class, function () {
			return Merchant::make();
		} );
	}

	/**
	 * @since 1.1.1
	 */
	public function boot(): void {
		add_action( 'givewp_register_payment_gateway', function ( PaymentGatewayRegister $paymentGatewayRegister ) {
			$paymentGatewayRegister->registerGateway( PaytmPaymentGateway::class );
		} );

		add_action( 'template_redirect', function () {
			if ( ! give_is_success_page() ) {
				return;
			}

			( new HandleProcessPaymentRedirect() )();
		}, 0 );
	}
}
